@@ -5,6 +5,12 @@ airy = {
     history: null,
     initialized: false,
 
+    defaults: {
+        'method': 'get',
+        'change_state': false,
+        'callback': null
+    },
+
     init: function() {
         if (!airy.initialized) {
             airy.history = window.History;
@@ -14,15 +20,29 @@ airy = {
             airy.initialized = true;
         }
         airy.request('get', airy.history.getState().hash);
+        airy.socket.emit('set_state', airy.history.getState().hash);
+    },
+
+    call: function(params) {
+        var options = $.extend({}, airy.defaults, params);
+        var url = airy.util.fix_url(airy.history.getState().hash);
+        options.url = airy.util.fix_url(options.url);
+        if (url == options.url || !options.change_state) {
+            var params = [options.method, options.url];
+            if (options.data)
+                $.merge(params, [options.data]);
+            if (typeof(options.callback) == "function")
+                $.merge(params, [options.callback]);
+            airy.socket.emit.apply(airy.socket, params);
+        } else {
+            airy.history.pushState(options, null, options.url);
+        }
     },
 
     request: function(method, url, data, nostate) {
+        // deprecated functionality
         if (airy.history.getState().hash == url || nostate) {
-            if (data) {
-                airy.socket.emit(method, url, data);
-            } else {
-                airy.socket.emit(method, url);
-            }
+            airy.call({method: method, url: url, data: data, change_state: !nostate});
         } else {
             airy.history.pushState({method: method, data: data}, null, url);
         }
@@ -44,6 +64,12 @@ airy = {
         },
         remove: function(target) {
             $(target).remove();
+        },
+        title: function(text) {
+            document.title = text;
+        },
+        redirect: function(url) {
+            airy.history.pushState({}, null, url);
         }
     },
 
@@ -51,17 +77,14 @@ airy = {
         history: function() {
             airy.history.Adapter.bind(window, 'statechange', function() {
                 var State = airy.history.getState();
-                if (State.data.data) {
-                    airy.socket.emit(State.data.method, State.hash, State.data.data);
-                } else {
-                    airy.socket.emit(State.data.method, State.hash);
-                }
+                airy.call({method: State.data.method, url: State.hash, data: State.data.data, change_state: false});
+                airy.socket.emit('set_state', State.hash);
             });
         },
         links: function() {
             $('a').live('click', function() {
                 if (airy.options.is_airy_link($(this))) {
-                    airy.request('get', $(this).attr('href'), null, airy.options.no_state_change(this));
+                    airy.call({url: $(this).attr('href'), change_state: !airy.options.no_state_change(this)});
                     return false;
                 }
             });
@@ -88,13 +111,20 @@ airy = {
 
     options: {
         is_airy_link: function(link) {
-            if (link.attr('href') && !link.attr('target') && !link.hasClass('no-airy')) {
+            if (!link.attr('href')) {
+                return false;
+            }
+            if (link.attr('href').substring(0, 7) == "http://" || link.attr('href').substring(0, 7) == "https://") {
+                return false;
+            }
+            if (link.attr('href') && !link.attr('target') && !link.attr('nofollow') && !link.hasClass('no-airy')) {
                 return true;
             }
             return false;
         },
 
         is_airy_form: function(form) {
+            if (window.location.href.substring(0, 7) == 'http://')
             if (!form.hasClass('no-airy')) {
                 return true;
             }
@@ -105,6 +135,18 @@ airy = {
             // when true airy will attempt to change the URL
             return $(item).hasClass('no-airy-state');
         }
+    },
+
+    util: {
+        fix_url: function(url) {
+            if (url.indexOf('.') == 0) {
+                url = url.substring(1);
+            }
+            if (url.indexOf('/') != 0) {
+                url = "/"+url;
+            }
+            return url;
+        }
     }
 }
 
